@@ -1,14 +1,14 @@
 package Sort::Sub::by_example;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-08-06'; # DATE
-our $DIST = 'Sort-Sub-by_example'; # DIST
-our $VERSION = '0.002'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2025-01-12'; # DATE
+our $DIST = 'Sort-Sub-by_example'; # DIST
+our $VERSION = '0.003'; # VERSION
+
 sub meta {
     return {
         v => 1,
@@ -36,17 +36,7 @@ sub gen_sorter {
     $example = [map {lc} @$example] if $is_ci;
 
     my $cmp = Sort::ByExample->cmp($example);
-    if ($is_reverse) {
-        return sub {
-            no strict 'refs';
-
-            my $caller = caller();
-            my $a = @_ ? $_[0] : ${"$caller\::a"};
-            my $b = @_ ? $_[1] : ${"$caller\::b"};
-        };
-    } else {
-        return $cmp;
-    }
+    #use Data::Dmp; dd $cmp
 }
 
 1;
@@ -64,7 +54,7 @@ Sort::Sub::by_example - Sort by example
 
 =head1 VERSION
 
-This document describes version 0.002 of Sort::Sub::by_example (from Perl distribution Sort-Sub-by_example), released on 2021-08-06.
+This document describes version 0.003 of Sort::Sub::by_example (from Perl distribution Sort-Sub-by_example), released on 2025-01-12.
 
 =head1 SYNOPSIS
 
@@ -114,6 +104,43 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sort-Sub-b
 
 Source repository is at L<https://github.com/perlancar/perl-Sort-Sub-by_example>.
 
+=head1 SEE ALSO
+
+L<Sort::ByExample>
+
+L<Sort::Sub::by_sortexample>
+
+L<Sort::Sub>
+
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2025 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sort-Sub-by_example>
@@ -122,21 +149,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 SEE ALSO
-
-L<Sort::ByExample>
-
-L<Sort::Sub>
-
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
